@@ -37,9 +37,10 @@ class AtomPubClient(object):
   host = None
   auth_token = None
   ssl = False # Whether to force all requests over https
+  xoauth_requestor_id = None
 
-  def __init__(self, http_client=None, host=None,
-               auth_token=None, source=None, **kwargs):
+  def __init__(self, http_client=None, host=None, auth_token=None, source=None,
+               xoauth_requestor_id=None, **kwargs):
     """Creates a new AtomPubClient instance.
 
     Args:
@@ -60,6 +61,7 @@ class AtomPubClient(object):
       self.host = host
     if auth_token is not None:
       self.auth_token = auth_token
+    self.xoauth_requestor_id = xoauth_requestor_id
     self.source = source
 
   def request(self, method=None, uri=None, auth_token=None,
@@ -93,7 +95,10 @@ class AtomPubClient(object):
     # HTTP request.
     for name, value in kwargs.iteritems():
       if value is not None:
-        value.modify_request(http_request)
+        if hasattr(value, 'modify_request'):
+          value.modify_request(http_request)
+        else:
+          http_request.uri.query[name] = str(value)
     # Default to an http request if the protocol scheme is not set.
     if http_request.uri.scheme is None:
       http_request.uri.scheme = 'http'
@@ -150,7 +155,7 @@ class AtomPubClient(object):
 
   def modify_request(self, http_request):
     """Changes the HTTP request before sending it to the server.
-    
+
     Sets the User-Agent HTTP header and fills in the HTTP host portion
     of the URL if one was not included in the request (for this it uses
     the self.host member if one is set). This method is called in
@@ -171,12 +176,49 @@ class AtomPubClient(object):
     if self.host is not None and http_request.uri.host is None:
       http_request.uri.host = self.host
 
+    if self.xoauth_requestor_id is not None:
+      http_request.uri.query['xoauth_requestor_id'] = self.xoauth_requestor_id
+
     # Set the user agent header for logging purposes.
     if self.source:
-      http_request.headers['User-Agent'] = '%s gdata-py/2.0.14' % self.source
+      http_request.headers['User-Agent'] = '%s gdata-py/2.0.18' % self.source
     else:
-      http_request.headers['User-Agent'] = 'gdata-py/2.0.14'
+      http_request.headers['User-Agent'] = 'gdata-py/2.0.17'
 
     return http_request
 
   ModifyRequest = modify_request
+
+
+class CustomHeaders(object):
+  """Add custom headers to an http_request.
+
+  Usage:
+    >>> custom_headers = atom.client.CustomHeaders(header1='value1',
+            header2='value2')
+    >>> client.get(uri, custom_headers=custom_headers)
+  """
+
+  def __init__(self, **kwargs):
+    """Creates a CustomHeaders instance.
+
+    Initialize the headers dictionary with the arguments list.
+    """
+    self.headers = kwargs
+
+  def modify_request(self, http_request):
+    """Changes the HTTP request before sending it to the server.
+
+    Adds the custom headers to the HTTP request.
+
+    Args:
+      http_request: An atom.http_core.HttpRequest().
+
+    Returns:
+      An atom.http_core.HttpRequest() with the added custom headers.
+    """
+
+    for name, value in self.headers.iteritems():
+      if value is not None:
+        http_request.headers[name] = value
+    return http_request
