@@ -14,9 +14,9 @@ import atom_tests.token_store_test
 import atom_tests.url_test
 import atom_tests.core_test
 import gdata_tests.apps.emailsettings.data_test
+import gdata_tests.apps.multidomain.data_test
 import gdata_tests.apps_test
 import gdata_tests.auth_test
-import gdata_tests.base_test
 import gdata_tests.books_test
 import gdata_tests.blogger_test
 import gdata_tests.calendar_test
@@ -41,10 +41,11 @@ def RunAllTests():
                          atom_tests.core_test,
                          atom_tests.token_store_test,
                          gdata_tests.client_test,
-                         gdata_tests.apps_test, 
+                         gdata_tests.apps_test,
                          gdata_tests.apps.emailsettings.data_test,
+                         gdata_tests.apps.multidomain.data_test,
                          gdata_tests.auth_test, 
-                         gdata_tests.base_test, gdata_tests.books_test,
+                         gdata_tests.books_test,
                          gdata_tests.calendar_test, gdata_tests.docs_test,
                          gdata_tests.health_test, gdata_tests.spreadsheet_test,
                          gdata_tests.photos_test, gdata_tests.codesearch_test,
