@@ -5,17 +5,23 @@ import unittest
 import module_test_runner
 import getopt
 import getpass
+
 # Modules whose tests we will run.
 import atom_tests.service_test
 import gdata_tests.service_test
 import gdata_tests.apps.service_test
-import gdata_tests.base.service_test
+import gdata_tests.books.service_test
 import gdata_tests.calendar.service_test
 import gdata_tests.docs.service_test
+import gdata_tests.health.service_test
 import gdata_tests.spreadsheet.service_test
 import gdata_tests.spreadsheet.text_db_test
 import gdata_tests.photos.service_test
-#import gdata_tests.contacts.service_test
+import gdata_tests.contacts.service_test
+import gdata_tests.blogger.service_test
+import gdata_tests.youtube.service_test
+import gdata_tests.health.service_test
+import gdata_tests.contacts.profiles.service_test
 
 
 def RunAllTests(username, password, spreadsheet_key, worksheet_key,
@@ -25,12 +31,16 @@ def RunAllTests(username, password, spreadsheet_key, worksheet_key,
                          gdata_tests.service_test, 
                          gdata_tests.apps.service_test,
                          gdata_tests.base.service_test, 
+                         gdata_tests.books.service_test, 
                          gdata_tests.calendar.service_test,
                          gdata_tests.docs.service_test, 
+                         gdata_tests.health.service_test,
                          gdata_tests.spreadsheet.service_test,
                          gdata_tests.spreadsheet.text_db_test,
-                         #gdata_tests.contacts.service_test,
-                         gdata_tests.photos.service_test]
+                         gdata_tests.contacts.service_test,
+                         gdata_tests.youtube.service_test,
+                         gdata_tests.photos.service_test,
+                         gdata_tests.contacts.profiles.service_test,]
   test_runner.settings = {'username':username, 'password':password, 
                           'test_image_location':'testimage.jpg',
                           'ss_key':spreadsheet_key,
