@@ -457,7 +457,7 @@ group.add_option("-f", "--description_file", action="store",
                  help="Optional path of a file that contains "
                       "the description when creating an issue.")
 group.add_option("-r", "--reviewers", action="store", dest="reviewers",
-                 metavar="REVIEWERS", default=",joe.gregorio@gmail.com",
+                 metavar="REVIEWERS", default=",afshar@google.com",
                  help="Add reviewers (comma separated email addresses).")
 group.add_option("--cc", action="store", dest="cc",
                  metavar="CC", default="gdata-python-client-library-contributors@googlegroups.com",
